<template>
    <v-card>
        <Head title="Reviews"/>
        <v-card-title>
            All Reviews
            <v-spacer/>
        </v-card-title>
        <v-divider/>
        <v-data-table :headers="headers" :items="reviews" class="elevation-1">
            <template v-slot:top>
                <v-dialog v-model="statusDialog" width="500" persistent>
                    <v-card>
                        <v-card-title class="text-h6 grey lighten-2">
                            Update status for `{{ editingReview.name }}`
                        </v-card-title>

                        <v-card-text class="mt-4 d-flex justify-center">
                            <v-chip-group v-model="editingReview.status" column>
                                <v-chip filter outlined v-for="status in statuses" :key="status" :value="status"
                                        :color="statusColour(status)">
                                    {{ status }}
                                </v-chip>
                            </v-chip-group>
                        </v-card-text>

                        <v-divider></v-divider>

                        <v-card-actions>
                            <v-btn color="info" text @click="closeStatusDialog">Close</v-btn>
                            <v-spacer></v-spacer>
                            <v-btn color="primary" text @click="updateReviewStatus">
                                Update
                                <v-icon right>mdi-pencil-outline</v-icon>
                            </v-btn>
                        </v-card-actions>
                    </v-card>
                </v-dialog>
            </template>
            <template v-slot:item.name="{ item }">
                {{ item.name | trim(25) }}
            </template>
            <template v-slot:item.index="{ index }">
                {{ index + 1 }}
            </template>
            <template v-slot:item.type="{ item }" class="text-truncate">
                <v-chip :color="({text: 'primary', video: 'info'})[item.type]" small>
                    {{ item.type.toLocaleUpperCase() }}
                </v-chip>
            </template>
            <template v-slot:item.rating="{ item }">
                <v-rating dense readonly :value="item.rating" x-small/>
            </template>
            <template v-slot:item.status="{item}">
                <v-chip small :color="statusColour(item.status)">{{ item.status.toUpperCase() }}</v-chip>
            </template>
            <template v-slot:item.email="{ item }" class="text-truncate">
                {{ item.email | trim(20) }}
            </template>
            <template v-slot:item.created_at="{ item }">
                {{ item.created_at | shortDate }}
            </template>
            <template v-slot:item.active="{item}">
                <v-icon :color="item.active? 'success':'error'" v-html="item.active ? 'mdi-check' : 'mdi-close'"/>
            </template>
            <template v-slot:item.actions="{ item, index }">
                <v-menu bottom dense left>
                    <template v-slot:activator="{ on, attrs }">
                        <v-btn icon small v-bind="attrs" v-on="on">
                            <v-icon>mdi-dots-vertical</v-icon>
                        </v-btn>
                    </template>
                    <v-list dense>
                        <v-list-item dense link @click="$go($route('review.edit', item.id))">
                            <v-list-item-title>
                                <v-icon color="info" left small>
                                    mdi-pencil
                                </v-icon>
                                Edit review
                            </v-list-item-title>
                        </v-list-item>
                        <v-list-item dense link @click="editReviewStatus(item)">
                            <v-list-item-title>
                                <v-icon color="info" left small>
                                    mdi-list-status
                                </v-icon>
                                Change status
                            </v-list-item-title>
                        </v-list-item>
                        <v-list-item dense link @click="updateStatus(index, item)">
                            <v-list-item-title>
                                <v-icon color="warning" left small>
                                    mdi-{{ item.active ? 'eye-off-outline' : 'eye-outline' }}
                                </v-icon>
                                {{ item.active ? 'Deactivate' : 'Activate' }}
                            </v-list-item-title>
                        </v-list-item>
                        <v-divider/>
                        <v-list-item dense link @click="deleteItem(item)">
                            <v-list-item-title>
                                <v-icon color="error" left small>mdi-trash-can-outline</v-icon>
                                Delete review
                            </v-list-item-title>
                        </v-list-item>
                    </v-list>
                </v-menu>
            </template>
        </v-data-table>
    </v-card>
</template>


<script>
import DashboardLayout from "../../Components/Layouts/Dashboard.vue";
import CategoryLayout from "./Review.vue";


export default {
    name: "ReviewIndex",
    layout: [DashboardLayout, CategoryLayout],
    data() {
        return {
            error: false,
            loading: false,
            statusDialog: false,
            headers: [
                {text: '', align: 'start', value: 'index'},
                {text: 'Name', sortable: true, value: 'name'},
                {text: 'Title', align: 'start', value: 'title'},
                {text: 'Type', value: 'type'},
                {text: 'Active', value: 'active', align: 'center'},
                {text: 'Status', value: 'status', align: 'center'},
                {text: 'Rating', value: 'rating', align: 'center'},
                {text: 'Created by', value: 'user.name'},
                {text: 'On', value: 'created_at'},
                {text: 'Action', value: 'actions', sortable: false, width: 100},
            ],
            reviews: this.$page.props.reviews,
            books: this.$page.props.books,
            customer: this.$page.props.customers,
            statuses: this.$page.props.statuses,
            editingReview: {},
        };
    },
    methods: {
        statusColour(status) {
            switch (status) {
                case 'reviewing':
                    return 'gray'
                case 'published':
                    return 'success'
                default:
                    return 'error';
            }
        },
        editReviewStatus(review) {
            this.editingReview = review
            this.statusDialog = true
        },
        updateReviewStatus() {
            this._confirmDialog({
                title: "Update status",
                message: 'Are you sure about this?',
                confirm: () => {
                    axios.post(this.$route('review.status', this.editingReview.id), {status: this.editingReview.status})
                        .then(resp => resp.data)
                        .then(data => {
                            const index = this.reviews.indexOf(this.reviews.find(r => r.id === this.editingReview.id))
                            this.reviews.splice(index, 1, data.review)
                            this.editingReview = {}
                            this.closeStatusDialog()
                        })
                }
            })
        },
        closeStatusDialog() {
            this.statusDialog = false
        },
        deleteItem(item) {
            this._confirmDialog({
                title: "Delete review",
                message: "Are you sure to delete this review?",
                confirm: () => {
                    this.$inertia.delete(this.$route('review.delete', item.id), {
                        only: ['reviews'],
                        onBefore: () => {
                        },
                        onSuccess: (page) => {
                            this.showSnack("Review successfully deleted.");
                            this.reviews = page.props.reviews
                        },
                        onError: (errors) => {
                            this.showSnack([errors, "error"]);
                        },
                        onFinish: visit => {
                        },
                    });
                }
            })
        },
        updateStatus(index, item) {
            this._confirmDialog({
                title: item.active ? "Hide review" : "Show review",
                message: 'Are you sure about this?',
                confirm: () => {
                    axios.post(this.$route('review.active', item.id))
                        .then(resp => resp.data)
                        .then(data => {
                            this.reviews[index].active = data.review.active
                        })
                }
            })
        },
    },
}
</script>

<style scoped>
</style>
